"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleCheckIdsRoutes = exports.handleChecksRoute = void 0;
const logger = require("../../../log");
const index_1 = require("../index");
const handleChecksRoute = (config) => {
    return async (_, res) => {
        try {
            const { httpCheckService, preflightCheckStore } = await (0, index_1.checksConfig)(config);
            const checkResults = [];
            const checks = await preflightCheckStore.getAll();
            for (const check of checks) {
                const checkResult = await httpCheckService.run(check.checkId);
                checkResults.push(checkResult);
            }
            res.status(200).json(checkResults);
        }
        catch (error) {
            logger.error({ error }, 'Error executing http checks');
            res.status(500).json({ error: error });
        }
    };
};
exports.handleChecksRoute = handleChecksRoute;
const handleCheckIdsRoutes = (config) => {
    return async (req, res) => {
        try {
            const { httpCheckService, preflightCheckStore } = await (0, index_1.checksConfig)(config);
            const check = await preflightCheckStore.get(req.params.checkId);
            if (check === null) {
                res.sendStatus(404);
                return;
            }
            const checkResult = await httpCheckService.run(check.checkId);
            res.status(200).json(checkResult);
        }
        catch (error) {
            logger.error({ error }, `Error executing http check with checkId: ${req.params.checkId}`);
            res.status(500).json({ error: error });
        }
    };
};
exports.handleCheckIdsRoutes = handleCheckIdsRoutes;
//# sourceMappingURL=checks-handler.js.map