"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signGitHubCommit = exports.commitSigningFilterRules = exports.commitSigningEnabled = exports.githubCommitSigningEnabled = void 0;
const logger = require("../../log");
const commit_1 = require("./github/commit");
const sign_1 = require("./pgp/sign");
const commit_signing_filter_rules_1 = require("./github/commit-signing-filter-rules");
function githubCommitSigningEnabled(config, options) {
    return ((0, exports.commitSigningEnabled)(config) &&
        (0, commit_1.isGitHubCreateCommitEndpoint)(options));
}
exports.githubCommitSigningEnabled = githubCommitSigningEnabled;
const commitSigningEnabled = (config) => {
    let gpgPassphraseConfigured = false;
    if (typeof config.GPG_PASSPHRASE !== 'undefined' &&
        config.GPG_PASSPHRASE !== '') {
        gpgPassphraseConfigured = true;
    }
    let gpgPrivateKeyConfigured = false;
    if (typeof config.GPG_PRIVATE_KEY !== 'undefined' &&
        config.GPG_PRIVATE_KEY !== '') {
        gpgPrivateKeyConfigured = true;
    }
    let gitCommitterNameConfigured = false;
    if (typeof config.GIT_COMMITTER_NAME !== 'undefined' &&
        config.GIT_COMMITTER_NAME !== '') {
        gitCommitterNameConfigured = true;
    }
    let gitCommitterEmailConfigured = false;
    if (typeof config.GIT_COMMITTER_EMAIL !== 'undefined' &&
        config.GIT_COMMITTER_EMAIL !== '') {
        gitCommitterEmailConfigured = true;
    }
    return (gpgPassphraseConfigured &&
        gpgPrivateKeyConfigured &&
        gitCommitterNameConfigured &&
        gitCommitterEmailConfigured);
};
exports.commitSigningEnabled = commitSigningEnabled;
function commitSigningFilterRules() {
    return (0, commit_signing_filter_rules_1.getCommitSigningGitHubFilterRules)();
}
exports.commitSigningFilterRules = commitSigningFilterRules;
/**
 * Sign GitHub commit with PGP private key and set `signature` property
 * for the GitHub commit payload.
 */
async function signGitHubCommit(config, body) {
    const commit = (0, commit_1.convertBodyToGitHubCommitPayload)(body, {
        committerName: config.GIT_COMMITTER_NAME,
        committerEmail: config.GIT_COMMITTER_EMAIL,
    });
    logger.debug({ commit }, 'github commit payload');
    const messageRaw = (0, commit_1.stringifyGitHubCommitPayload)(commit);
    logger.debug({ messageRaw }, 'raw message before creating pgp signature');
    const signature = await (0, sign_1.createSignature)({
        messageRaw: messageRaw,
        privateKey: {
            armoredKey: config.GPG_PRIVATE_KEY,
            passphrase: config.GPG_PASSPHRASE,
        },
    });
    logger.debug({ signature }, 'commit pgp signature');
    commit.signature = signature;
    return Promise.resolve(JSON.stringify(commit));
}
exports.signGitHubCommit = signGitHubCommit;
//# sourceMappingURL=index.js.map